# Terminal Typing Test

[![Fawaz Shah](https://circleci.com/gh/fawazshah/terminal-typing-test.svg?style=shield)](https://app.circleci.com/pipelines/github/fawazshah/terminal-typing-test)

Find your typing speed through the command line!

Install with `pip install terminal-typing-test`. Once installed, run `typingtest` from the command line.

